@@ -13,6 +13,7 @@ void pygconf_register_classes (PyObject *d);
 void pygconf_add_constants(PyObject *module, const gchar *strip_prefix);
 		
 extern PyMethodDef pygconf_functions[];
+extern PyTypeObject PyGConfEngine_Type;
 
 DL_EXPORT(void)
 initgconf (void)
@@ -27,4 +28,6 @@ initgconf (void)
 	pygconf_register_classes (d);
 	pygconf_add_constants (m, "GCONF_");
 	pygconf_register_engine_type (m);
+
+        PyModule_AddObject(m, "Engine", (PyObject *) &PyGConfEngine_Type);
 }
