@@ -2,20 +2,17 @@ import os
 import sys
 
 if not os.environ.has_key('DIST_CHECK'):
-  sys.path.insert(0, '..')
+    sys.path = ['..', '../gnomevfs', '../gnomecanvas'] + sys.path
 
 import ltihooks
+ltihooks.install()
 
 import bonobo
+import gnomevfs
 import bonobo.ui
 import gconf
 import gnome
 import gnome.ui
-import gnome.vfs
-import gnome.nautilus
-import gnome.applet
-import gnomeprint
-import gnomeprint.ui
-import gtkhtml2
+import gnomecanvas
 
 ltihooks.uninstall()
